@@ -1,5 +1,5 @@
 package Mira::Control::Plugin::Load;
-$Mira::Control::Plugin::Load::VERSION = '00.07.26';
+$Mira::Control::Plugin::Load::VERSION = '00.07.27';
 
 use strict;
 use warnings;
@@ -23,13 +23,11 @@ sub check {
   {
     if (my $chkinst = check_install( module => "Mira::Plugin::$plugin"))
     {
-      say "PLUGINS >>> package Mira::Plugin::$plugin is Loaded";
       push @check, "Mira::Plugin::$plugin";
       next;
     }
     if (my $chkinst = check_install( module => $plugin))
     {
-      say "PLUGINS >>> $plugin is Loaded";
       push @check, $plugin;
       next;
     }
